<?php

namespace LTK\Foundation\View;

class Breadcrumb {

	/**
	 * Displays HTML of Bootstrap breadcrumbs
	 *
	 * @return string HTML of a breadcrumb
	 */
	static public function getBreadcrumb() {

		// Show nothing in front page
		if (is_front_page()) {
			return;
		}

		$list = self::generateBreadcrumbList();
		
		if (empty($list)) {
			return '';
		}

		// No escaping here, all escaping is already happening at generateBreadcrumbList()
		$html = '<ol class="breadcrumb" itemscope itemtype="http://schema.org/BreadcrumbList">';

		$position = 1;
		foreach ($list as $item_text => $item_url) {
			$html .= '<li itemprop="itemListElement" itemscope itemtype="http://schema.org/ListItem">';

			// Is the item a list of items instead? (post belongs to >1 categories)
			if (is_array($item_url)) {
				
				$commas_total = count($item_url) - 1;
				$commas_written = 0;
				foreach ($item_url as $category_text => $category_url) {
					$html .= '<a itemprop="item" href="' . $category_url . '"><span itemprop="name">' . $category_text . '</span><meta itemprop="position" content="' . $position . '"></a>';
					if ($commas_written < $commas_total) {
						$html .= ', ';
					}
					$commas_written++;
				}
				
			} else {
				
				if (! is_null($item_url)) {
					$html .= '<a itemprop="item" href="' . $item_url . '">';
				}
				
				$html .= '<span itemprop="name">' . $item_text . '</span><meta itemprop="position" content="' . $position . '">';
				
				if (! is_null($item_url)) {
					$html .= '</a>';
				}
				
			}

			$html .= '</li>';
			$position++;
		}

		$html .= '</ol>';

		return $html;

	}

	/**
	 * Generates an array for breadcrumb trails
	 *
	 * @return array Items of the breadcrumb, in the form title => url|null
	 */
	static protected function generateBreadcrumbList() {

		// Recursive function to find multi category path
		$category_path = function($category) use (&$category_path) {

			$category_obj = get_category($category);
			$parent = $category_obj->category_parent;

			if (! $parent) {
				return [esc_html(get_the_category_by_ID($category)) => esc_url(get_category_link($category))];
			}

			return array_merge($category_path($parent), [esc_html(get_the_category_by_ID($category)) => esc_url(get_category_link($category))]);

		};

		// 0. Declaration
		$list = [];

		// 1. Website index, not escaped for obvious reasons
		$list['<i class="fa fa-home"></i>'] = esc_url(home_url());

		// 2. Posts page, if configured
		$settings = wp_load_alloptions();
		if ($settings['show_on_front'] == 'page' && $settings['page_for_posts'] && ! is_page()) {
			$list[esc_html(get_the_title($settings['page_for_posts']))] = esc_url(get_page_link($settings['page_for_posts']));
		}

		// 3. Ending A: Search page & search term
		if (is_search()) {
			$search = get_search_query();
			if (! empty($search)) {
				$list[esc_html(sprintf(__('Search: %s', 'ltk-foundation'), $search))] = null;
			} else {
				// Do not show breadcrumb if search is empty (WordPress shows index here)
				$list = [];
			}
			return $list;
		}

		// 3. Ending B: Error 404
		if (is_404()) {
			$list[esc_html(__('Error 404', 'ltk-foundation'))] = null;
			return $list;
		}

		// 3. Ending C: Author page
		if (is_author()) {
			$author = get_the_author();
			$list[esc_html(sprintf(__('Author: %s', 'ltk-foundation'), $author))] = esc_url(home_url('/') . 'author/' . $author);
			return $list;
		}

		// 3. Ending D: Tag page
		if (is_tag()) {
			$tag = get_term_by('name', single_tag_title('', false), 'post_tag');
			$list[esc_html(single_tag_title('', false))] = esc_url(get_tag_link($tag->term_id));
			return $list;
		}

		// 3. Ending E: Category
		if (is_category()) {
			return array_merge($list, $category_path(get_query_var('cat')));
		}

		// 3. Ending F: Page
		if (is_page()) {
			$list[esc_html(get_the_title())] = null;
			return $list;
		}

		// 3. Ending G: Single post
		if (is_single()) {
			$post_categories = get_the_category();

			// Single category = recursive search for parents
			if (count($post_categories) == 1) {
				$the_category = array_shift($post_categories);
				$list = array_merge($list, $category_path($the_category->cat_ID));
			} else {
				$_list = [];
				foreach ($post_categories as $category) {
					$_list[esc_html($category->cat_name)] = esc_url(get_category_link($category->cat_ID));
				}
				$list[] = $_list;
			}
			
			// Put the post ID when the post has no title
			$_title = get_the_title(get_the_id());
			if (empty($_title)) {
				$_title = get_the_id();
			}

			$list[esc_html($_title)] = null;

			return $list;
		}

		// 3. Ending H: Archive page
		if (is_archive()) {
			$year = get_query_var('year');
			if ($year) {
				$list[esc_html($year)] = esc_url(get_year_link($year));
				$month = get_query_var('monthnum');
				if ($month) {
					$list[esc_html(ucwords(date_i18n('F', strtotime("$year-$month-01"))))] = esc_url(get_month_link($year, $month));
					$day = get_query_var('day');
					if ($day) {
						$list[esc_html(date_i18n('d', strtotime("$year-$month-$day")))] = esc_url(get_day_link($year, $monthnum, $day));
					}
				}
			}
			return $list;
		}

	}

}
